
#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yyget_lval
#define yyget_lval_ALREADY_DEFINED
#else
#define yyget_lval yyget_lval
#endif

#ifdef yyset_lval
#define yyset_lval_ALREADY_DEFINED
#else
#define yyset_lval yyset_lval
#endif

#ifdef yyget_lloc
#define yyget_lloc_ALREADY_DEFINED
#else
#define yyget_lloc yyget_lloc
#endif

#ifdef yyset_lloc
#define yyset_lloc_ALREADY_DEFINED
#else
#define yyset_lloc yyset_lloc
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 194
#define YY_END_OF_BUFFER 195
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1051] =
    {   0,
        0,    0,  195,  193,    1,    1,    1,  193,  187,   23,
       24,   11,   16,   12,  109,   13,    2,    2,    2,   14,
       16,  111,  193,  193,  193,  187,  193,  193,  110,  193,
      193,  193,  193,  193,  193,  193,  193,  193,  193,  193,
      193,  193,  193,  187,  193,   21,   22,  193,  111,  193,
      193,  193,  193,  193,  193,  193,  193,  193,  193,  193,
      193,    1,    0,    0,    0,    0,    0,  107,   15,    4,
        0,    2,   32,   33,    2,    2,    3,    0,  111,    0,
        0,    0,  111,  111,    0,    0,    0,    0,    0,    0,
      188,    0,    0,  188,    0,    0,    0,  187,    0,   47,

        0,    0,  127,    0,  126,    0,    0,    0,  188,    0,
      123,    0,  124,  125,   43,    0,    0,    0,    0,    0,
        0,   25,    0,    0,    0,   48,    0,   26,  129,   49,
        0,    0,   46,  111,   44,    0,    0,  128,    0,    0,
      184,   45,    0,  182,  185,  186,    5,  111,    0,  109,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  188,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   32,    0,   33,    0,    0,  187,    0,

       71,   75,    0,  111,    0,    0,    0,  188,    0,   79,
      116,  136,    0,  144,    0,    0,    0,    0,    0,    0,
       69,    0,    0,   54,    0,   47,    0,    0,    0,  148,
       68,  133,    0,    0,    0,   74,    0,   73,    0,    0,
      130,    0,   84,   70,   72,  105,  132,    0,    0,    0,
        0,   50,   43,  104,   78,   77,    8,  106,    0,    0,
        0,    0,    0,   55,  143,  135,   48,    0,    0,    0,
       76,    0,    0,   56,   49,    0,    0,   53,    0,   46,
       51,   44,  188,  187,    0,  134,  142,  188,    0,   52,
       45,    0,    0,  182,    0,    0,  111,  111,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  111,    0,    0,    0,    0,
      111,    0,    0,   12,    0,  111,  188,  163,  164,  110,
      158,  161,  160,  159,    0,  162,   27,   32,   33,   10,
        0,    0,   71,    0,   75,    0,    0,    0,    0,    0,
       17,   79,    0,    0,    0,    0,    0,    0,    0,    0,
       20,    0,    0,    0,    0,   69,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   68,    0,    0,    0,    0,
        0,    0,   85,   74,   62,    0,   73,   61,    0,    0,
        0,    0,    0,   70,    0,    0,   82,    0,   72,    0,

        0,    0,    0,    0,    0,   78,    0,   77,    0,    6,
        0,    0,  168,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   76,   76,    0,    0,    0,    0,    0,  143,
        0,    0,    0,   42,   41,    0,    0,    0,    0,    0,
        0,   29,    0,    0,    0,    0,    0,    0,  179,  174,
        0,    0,    0,    0,    0,    0,  173,    0,  177,  177,
      178,    0,  175,  178,    0,    0,  176,    0,    0,    0,
        0,  188,    0,    0,    0,  108,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   28,    0,   87,   60,    0,
       83,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,  152,  112,
        0,    0,    0,    0,    0,    0,    0,    0,  133,    0,
        0,    0,  170,  169,  112,  130,    0,  138,    0,   59,
      131,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  171,    0,    0,    0,
        0,    0,  166,    0,  157,    0,    0,    0,    0,    0,
      154,    0,   42,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   63,
        0,  112,    7,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   30,    0,    0,    0,    0,    0,   38,    0,
        0,    0,    0,    0,    0,  141,    0,  145,    0,    0,
        0,  139,    0,    0,    0,  172,    0,   34,  115,    0,
        0,    0,  155,  156,    0,  143,  150,  135,    0,    0,
        0,  167,    0,    0,   40,    0,   19,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  186,
        0,    0,  179,  174,  112,    0,    0,    0,   96,    0,
        0,    0,  173,  177,    0,  175,  178,    0,  176,    0,

        0,    0,    0,    0,    0,    0,  163,  164,  158,  161,
      160,  159,  165,  162,  113,  112,    0,    0,    0,  181,
        0,  144,    0,    0,    0,    0,    0,    0,    0,  119,
       38,    0,    0,  148,    0,   57,   80,    0,   86,  180,
      146,    0,    0,    0,    0,    0,   34,  115,    0,    0,
       65,   89,  112,  120,    0,  153,    0,  121,   40,   18,
      111,    0,   35,    9,    0,  149,    0,  142,  184,    0,
       31,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,   67,  116,  136,
      151,    0,    0,    0,    0,    0,   58,  122,  119,   81,
        0,    0,    0,  132,    0,  117,   66,   90,  120,   39,
        0,    0,  121,   37,   35,  134,    0,  182,  185,    0,
        0,    0,    0,  112,    0,   98,   97,   94,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  116,  183,    0,   91,    0,  112,  122,    0,
        0,  147,    0,  140,  117,   39,   64,   88,   37,   36,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  163,  164,  158,  161,  160,  159,  162,  118,
      188,    0,    0,   36,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  175,    0,    0,    0,    0,    0,
      192,  112,  114,  113,    0,    0,  118,  112,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   99,   95,    0,    0,
        0,  102,    0,    0,    0,    0,    0,    0,    0,   92,
      191,  192,  112,  114,  113,    0,    0,  190,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  137,    0,  174,  103,  101,
        0,    0,   93,  191,  189,  190,  190,  190,    0,    0,
        0,    0,    0,    0,    0,    0,  100,  189,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  179,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    1,    1,    1,    6,    1,    7,
        8,    1,    9,   10,   11,   12,   13,   14,   14,   15,
       14,   16,   14,   17,   18,   17,   17,   19,   20,    1,
        1,    1,    1,    1,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,    1,   48,    1,    1,    1,   49,   50,   51,   52,

       53,   54,   55,   56,   57,   58,   59,   60,   61,   62,
       63,   64,   65,   66,   67,   68,   69,   70,   71,   72,
       73,   74,    1,   75,    1,   76,    1,   77,   78,   79,
       80,   81,   82,   83,   84,   85,   86,   87,   88,   89,
       90,   91,   92,   93,   94,   95,   96,   97,   98,    1,
       99,  100,  101,  102,  103,  104,  105,  106,  107,  108,
      109,    1,    1,  110,  111,    1,  112,  113,  114,    1,
      115,  116,    1,    1,  117,  118,  119,  120,  121,  122,
      123,  124,  125,  126,  127,  128,  129,  130,  131,  132,
      133,    1,    1,  134,  135,    1,    1,    1,    1,    1,

        1,    1,  136,    1,    1,    1,    1,  137,  138,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,  139,  140,    1,  141,  142,
      143,    1,  144,    1,    1,    1,    1,    1,  145,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[146] =
    {   0,
        1,    1,    2,    1,    1,    1,    3,    3,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    1,    3,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    3,    3,    3,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[1055] =
    {   0,
        0,    0, 2108, 2109,  144,  147,  151, 2102, 2109, 2109,
     2109, 2109, 2102, 2109, 2109, 2109,  148,  156,  164, 2109,
        0,  154,  130,  166,  204,  206,  177,  181, 2109,  254,
      162,  207,  267,  172,  218,  181,  190,  259,  294,  313,
      237,  296,  317, 2109,  283, 2109, 2109, 2030, 2109, 1996,
       48, 2010,  284,  173,  315,   81,  162,  257,  216, 2018,
      132,  307, 1993, 2023, 2022,  221, 2093, 2109, 2109, 2109,
      319,  404,  352,  353,  441,  416, 2109,  269, 2109,  320,
     1962,  329, 2109,  344,  336,  368,  372,  382,  388,  405,
      401,  436,  403,  404, 1982,  411,  456, 2109,  444,  471,

     1981,  424,  432,  440,  434,  439,  484,  451, 2109,  464,
      453,  498,  482,  498,  487,  482,  483,  486,  503,  490,
      506, 2109,  540,  513,  512,  540,  538, 2109,  522,  565,
     1985,  529,  566, 2109,  563,  543,  561,  549,  561,  553,
      562,  593,  565,  571,  563,  572, 2109,  573,  582, 2109,
     1956,  176, 1955, 1953, 1953, 1952, 1951,  199,  289, 1950,
      355, 1949, 1948,  588, 1947, 1946, 1944,  590, 1944, 1942,
      560, 1984, 1983,  559, 1947, 1993, 1968, 1963, 1994,  554,
     1950, 1956, 1965, 1975, 1972,  536, 1961, 1949, 1988,  596,
      617,  635,  609, 2052,  610, 2051, 2044,  619, 2109, 1932,

      647,  640,  631, 2109,  623,  621,  634, 2109,  640,  667,
      641,  659,  643,  658,  660,  654,  663,  651,  670,  670,
      686,  680,  666, 2109,  671,  682,  674,  674,  694,  684,
      717,  708,  698,  695,  706,  718,  718,  730,  712,  705,
      723,  715, 2109,  749, 2048, 2109,  727,  713,  726,  716,
     1945, 2109,  750, 2109,  745,  750, 2109, 2109,  746,  744,
      758,  752,  769, 2109,  774,  772,  755,  758,  782,  775,
      793,  766,  773, 2109,  791,  787,  789, 2109,  784,  788,
     2109,  789, 2109, 2109,  802,  820,  800, 2109,  811, 2109,
      812,  817,  809,  816,  826,  828, 2109, 2109,  735, 1926,

      120, 1934, 1965, 1937, 1922, 1925,  124,  783,  178,  408,
     1929, 1928, 1971, 1918, 1916, 2109, 1915, 1928, 1922, 1965,
     2109, 1925, 1962, 2109,  437, 2109, 2109, 1899, 1898, 2109,
     1897, 1896, 1895, 1894, 1893, 1892,  814, 2109, 2109, 2109,
      821,  820, 2109,  831, 2109,  826,  835,  849,  832,  857,
     2109, 2109,  850,  845,  851,  862,  855,  856,  867,  869,
     2109,  872,  875,  866,  864, 2109,  862,  866,  884,  881,
      867,  887,  871,  887,  891, 2109,  898,  892,  894,  887,
      902,  906, 2109, 2109, 2109,  899, 2109, 2109,  901,  916,
      913,  921,  922, 2109,  920,  921, 2109,  927, 2109,  918,

      934,  931,  916,  940,  941, 2109,  930, 2109,  942, 2109,
      925,  931, 2109,  932,  955,  934,  953,  942,  945,  960,
      957,  963, 2109,  989,  977,  962,  983,  977,  983,  988,
      991, 1921,  972,  976,  993,  983,  981,  982,  987, 1003,
     1003, 2109,  990,  992,  995, 1014, 1895, 1893, 1892, 1892,
     1890, 1890, 1889,  901, 1887, 1886, 2109, 1886, 2109, 1884,
     2109, 1884, 1883, 1882, 1881, 1879, 2109, 1879, 1877, 1877,
     1876, 1875, 1873, 1873, 1039, 2109, 1932, 1905, 1904, 1903,
     1902, 1901, 1900, 1903, 1898, 2109, 1010, 2109, 2109, 1011,
     2109, 1028, 1018, 1030, 1036, 1020, 1039, 1043, 1036, 1039,

     1029, 1030, 1036, 1032, 1037, 1034, 1052, 1034, 2109, 2109,
     1886, 1054, 1031, 1048, 1051, 1060, 1047, 1062, 2109, 1995,
     1050, 1066, 2109, 2109, 2109, 2109, 1077, 2109, 1086, 2109,
     2109, 1084, 1077, 1085, 1079, 1075, 1083, 1075, 1094, 1100,
     1101, 1103, 1104, 1106, 1093, 1094, 2109, 1101, 1110, 1108,
     1109, 1119, 2109, 1108, 2109, 1122, 1100, 1108, 1122, 1139,
     2109, 1137, 1141, 1145, 1127, 1147, 1150, 1151, 1156, 1140,
     1139, 1157, 1158, 1156, 1877, 1920, 1918, 1863, 1912, 1865,
      274, 1865, 1914, 1898, 1910, 1857, 1908, 1855, 1862, 1865,
     1863, 1903, 1861, 1902, 1851, 1852, 1849, 1898, 1845, 1080,

     1870, 1869, 1868, 1867, 1866, 1865, 1857, 1863, 1152, 2109,
     1153, 2109, 2109, 1164, 1174, 1168, 1170, 1176, 1166, 1179,
     1167, 1191, 2109, 1174, 1197, 1181, 1199, 1194, 1183, 1201,
     1193, 1201, 1187, 1195, 1209, 2109, 1196, 2109, 1850, 1210,
     1209, 2109, 1214, 1216, 1211, 2109, 1221, 1206, 1212, 1232,
     1214, 1228, 2109, 2109, 1228, 2109, 2109, 2109, 1232, 1241,
     1248, 2109, 1252, 1248, 1237, 1252, 2109, 1250, 1261, 1239,
     1252, 1264, 1260, 1252, 1265, 1269, 1260, 1274, 1275, 2109,
     1827, 1827, 1826, 1824, 1162, 1824, 1822, 1821, 2109, 1820,
     1820, 1818, 1818, 1817, 1815, 1815, 1814, 1812, 1812, 1811,

     1809, 1170, 1809, 1807, 1806, 1806, 1800, 1799, 1798, 1797,
     1796, 1795, 2109, 1794, 2109, 2109, 1263, 1282, 1286, 2109,
     1292, 2109, 1294, 1278, 1287, 1297, 1303, 1283, 1303, 1292,
     2109, 1294, 1294, 2109, 1819, 2109, 2109, 1799, 2109, 2109,
     2109, 1817, 1310, 1306, 1313, 1312, 2109, 2109, 1304, 1320,
     2109, 2109, 2109, 1308, 1303, 2109, 1326, 1310, 2109, 2109,
     2109, 1305, 1313, 2109, 1328, 2109, 1816, 2109, 2109, 1344,
     2109, 1342, 1344, 1851, 1807, 1801, 1851, 1282, 1339, 1809,
     1837, 1836, 1845, 1804, 1830, 1798, 1789, 1840, 1796, 1798,
     1839, 1795, 1796, 1831, 1794, 1834, 1785, 1832, 1830, 1784,

     1807, 1806, 1805, 1804, 1803, 1802, 1801, 2109, 1393, 2109,
     2109, 1407, 1414, 1411, 1403, 1403, 2109, 1414, 2109, 2109,
     1401, 1785, 1412, 2109, 1403, 1404, 2109, 2109, 2109, 1405,
     1407, 1421, 2109, 1408, 2109, 2109, 1403, 2109, 2109, 1760,
     1760, 1758, 1758, 1244, 1757, 2109, 2109, 2109, 1755, 1755,
     1754, 1753, 1751, 1751, 1750, 1749, 1748, 1746, 1746, 1744,
     1743, 1743, 1741, 1741, 1739, 1765, 1764, 1763, 1762, 1761,
     1760, 1759, 2109, 2109, 1422, 2109, 1409, 2109, 2109, 1426,
     1414, 2109, 1753, 2109, 2109, 2109, 2109, 2109, 2109, 1414,
     1790, 1738, 1789, 1734, 1745, 1786, 1743, 1739, 1734, 1767,

     1740, 1725, 1738, 1732, 1777, 1721, 1773, 1763, 1730, 1761,
     1728, 1770, 2109, 2109, 2109, 2109, 2109, 2109, 2109, 1415,
     2109, 1421, 1427, 2109, 1708, 1707, 1707, 1706, 1704, 1703,
     1702, 1702, 1700, 1700, 2109, 1698, 1698, 1696, 1695, 1695,
     1246, 1249, 1251, 1253, 1694, 1320, 2109, 2109, 1695, 1750,
     1739, 1704, 1700, 1748, 1735, 1746, 1699, 1738, 1701, 1740,
     1689, 1740, 1727, 1693, 1367, 1424, 1401, 1471, 1448, 1505,
     1482, 1539, 1691, 1516, 1573, 1699, 2109, 2109, 1674, 1674,
     1672, 2109, 1668, 1666, 1642, 1607, 1574, 1494, 1461, 2109,
     1398, 1400, 1402, 1404, 1406, 1426, 1380, 1408, 1627, 1383,

     1331, 1309, 1307, 1265, 1256, 1295, 1249,  807,  610, 1550,
     1618,  618,  520, 1595, 1652, 2109,  493, 2109, 2109, 2109,
      490,  441, 2109, 1547, 1549, 1551, 1553, 1555,  419,  444,
      415, 1629, 1686, 1663,  344,  312, 2109, 1660,  297,  281,
      259,  250,  289,  234,  214,  169,   78,   39, 2109, 2109,
     1798, 1801, 1804, 1807
    } ;

static const flex_int16_t yy_def[1055] =
    {   0,
     1050,    1, 1050, 1050, 1050, 1050, 1050, 1051, 1050, 1050,
     1050, 1050, 1052, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1053, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1051, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1054, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1054, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,    0,
     1050, 1050, 1050, 1050
    } ;

static const flex_int16_t yy_nxt[2255] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   17,   19,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   29,    4,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
       41,   42,   43,    4,   44,   45,   46,   47,   22,   23,
       24,   25,   26,   27,   28,   29,    4,   30,   31,   32,
       33,   34,   35,   36,   37,   38,   39,   40,   41,   42,
       43,    4,   44,   45,   48,   49,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,

        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,   50,   51,   52,   53,   54,   55,   56,
       57,   58,   59,   60,   61,   62,   62,   62,   62,   62,
       62,   71,   62,   62,   62,  148,  149,  174,   86,   71,
      175,   72,   72,   72,   72,   72,  457,   71,   73,   72,
       72,   75,   72,   72,   66,   78,   73,   76,   76,   76,
       76,   76,  108,   74,   73,   79,   86,   80,   81,   82,
       87,   74,   83,   88,   84,   85,   73,   89,  450,   74,

     1049,   99,   66,   78,   73,  102,  117,  451,  122,  103,
      108,   74,   73,   79,  100,   80,   81,   82,   87,   74,
       83,   88,   84,   85,   90,   89,   96,   74,   91,   99,
      123,  109,   92,  102,  117,  110,  122,  103,   93,   97,
      118,  190,  100,  119,   94,   98,  176,  111,  120,  169,
      170,  457,   90,  121,   96,  458,   91,  185,  123,  109,
       92,  186,  187,  110,  136,  177,   93,   97,  118,  190,
      137,  119,   94,   98,  104,  111,  120,   63,  105,  124,
       63,  121,   64,   65,   63,   64,   65,  112,  106,   64,
       65,  113,  136,  182,  107,  114,  461,  198,  137,  125,

      462,  115,  104,  145,  116, 1048,  105,  124,   62,   62,
       62,  101,  300,  301,  126,  112,  106,  146,  127,  113,
      138,  128,  107,  114,  139,  198,  183,  125,  129,  115,
      140,  145,  116,  141,  130,  307,  308,  132,   95,  191,
      133,  142,  126,  199,  143,  146,  127,  134,  138,  128,
     1047,  144,  139,  135,  192,  178,  129,  179,  140, 1046,
      180,  141,  130,  193,  195,  132,  201,  191,  133,  142,
      202,  199,  143,  203,  181,  134,  151, 1045,  152,  144,
      153,  135,  192,  154,  194,  196, 1044,  155,  156,  157,
      158,  171,  159,  160,  201,  161, 1043,  172,  202,  173,

      162,  203,  687,  163,  688,  164,  204,   71,  165,  205,
      206, 1042,  194,  196,  166,  167,  168,   76,   76,   76,
       76,   76,  207,  210,   73,  309,  310, 1041,  131,   76,
       76,   76,   76,   76,  204,  214,  215,  205,  206,   74,
       63,  476,  216,  208,   71,   64,   65,  209, 1040,  218,
      207,  210,   73,  197,   76,   76,   76,   76,   76,  219,
      211,   73,  229,  214,  215,  221,  230,   74,  212,  213,
      216,  208,  222,  231,  232,  209,   74,  218,  220,  233,
     1039,  223,  224,  239,  463,  240,  241,  464,  211,   73,
      229,  312,  313,  221,  230,  225,  212,  213,  252,  226,

      222,  231,  232, 1037,   74,  227,  220,  233,  234,  223,
      246,  239,  235,  240,  241,  236,  237,  238,  242,  247,
      253,  254,  248,  225,  255,  256,  243,  226,  257,  258,
      259,  249, 1036,  227,  262,  244,  234,  250,  246,  263,
      235, 1035,  245,  236,  237,  238,  242,  247,  253,  254,
      248,  264,  255,  256,  243,  273,  257,  258,  259,  249,
      260,  265,  262,  244,  268,  250,  277,  263,  261,  269,
      245,  270,  266,  271,  281,  477,  274,  278, 1031,  267,
      283,  272,  286,  273,  284,  287,  288,  282,  260,  265,
      289,  285,  268,  293,  277,  294,  261,  269,  275,  270,

      266,  271,  295,  279,  290,  296,  280,  267,  283,  272,
      286,  297,  284,  287,  288,  282,  291,  292,  289,  285,
      298,  293,  316,  294,  321,  324,  275, 1030,  193, 1029,
      295,  279,  251,  296,  280,   62,  199,  150,  331,  297,
      337,  194,  196,  341,  291,  292,  195, 1026,  298,  194,
      316,  345,  321,  324,  324,  324,  324,  324,  343,  347,
      348,  349,  326,  325,  325,  325,  332,  196,  337,  194,
      196,  341,  350,  351,  354,  344,   62,  194,  352,  355,
      346,  356,  357,  359,  361,  362,  358,  347,  348,  349,
      363,  353,  364,  360,  365,  196, 1025,  366,  370,  371,

      350,  351,  354,  344,  368,  372,  327,  355,  346,  356,
      357,  359,  361,  362,  358,  373,  374,  369,  363,  353,
      364,  360,  365,  367,  317,  375,  370,  371,  376,  384,
      467,  379,  368,  372,  327,  380,  381,  382,  386,  383,
      389,  387,  390,  373,  374,  369,  391,  392,  393,  400,
      401,  367,  402,  375,  388,  403,  406,  377,  378,  379,
      394,  408,  385,  380,  381,  382,  386,  383,  389,  407,
      390,  395,  396,  404,  391,  392,  393,  400,  401,  410,
      402,  411,  388,  403,  409,  377,  378,  397,  398,  405,
      385,  412,  413,  414,  415,  419,  417,  407,  420,  395,

      396,  404,  421,  422,  423,  425,  426,  410,  430,  411,
      418,  431,  409,  416,  427,  397,  398,  405,  433,  412,
      413,  414,  415,  419,  417,  434,  420,  435,  428,  429,
      421,  422,  424,  425,  426,  436,  430,  439,  418,  431,
      440,  416,  427,  437,  438,  441,  433,  442,  443,  444,
      445,  446,  486,  434,  447,  435,  428,  429,  487,  488,
      424,  459,  489,  436,  490,  439,  491,  448,  440,  492,
      493,  437,  438,  441,  460,  442,  443,  444,  445,  446,
      486,  494,  495,  496,  497,  498,  487,  488,  499,  500,
      489,  501,  490,  502,  491, 1023,  503,  492,  493,  504,

      505,  506,  507,  508,  509,  510,  512,  513,  514,  494,
      495,  496,  497,  498,  515,  516,  499,  500,  517,  501,
      518,  502,  519,  432,  503,  520,  521,  504,  505,  506,
      507,  508,  509,  510,  512,  513,  514,  522,  523,  524,
      525,  526,  515,  516,  527,  529,  517,  530,  518,  531,
      519,  532,  533,  520,  521,  534,  535,  536,  537,  528,
      538,  539,  540,  541,  542,  522,  523,  524,  525,  526,
      543,  544,  527,  529,  547,  530,  548,  531,  545,  532,
      533,  549,  550,  534,  535,  536,  537,  528,  538,  539,
      540,  541,  542,  551,  546,  552,  553,  555,  543,  544,

      423,  556,  547,  557,  548,  558,  545,  559,  560,  549,
      550,  561,  562,  554,  563,  511,  564,  565,  566,  567,
      568,  551,  546,  552,  553,  555,  569,  570,  571,  556,
      572,  557,  573,  558,  574,  559,  560,  582,  583,  561,
      562,  554,  563,  476,  564,  565,  566,  567,  568,  609,
      610,  611,  612,  613,  569,  570,  571,  614,  572,  615,
      573,  616,  574,  617,  618,  619,  620,  621,  622,  623,
      624,  625,  626,  627,  628,  629,  630,  609,  610,  611,
      612,  613,  631,  632,  633,  614,  634,  615,  636,  616,
      637,  617,  618,  619,  620,  621,  622,  623,  624,  625,

      626,  627,  628,  629,  630,  638,  640,  641,  643,  644,
      631,  632,  633,  645,  634,  646,  636,  647,  637,  648,
      649,  650,  642,  653,  654,  651,  655,  656,  657,  658,
      659,  660,  661,  638,  640,  641,  643,  644,  652,  662,
      663,  645,  664,  646,  665,  647,  666,  648,  649,  650,
      642,  653,  654,  651,  655,  656,  657,  658,  659,  660,
      661,  667,  545,  668,  669,  670,  652,  662,  663,  671,
      664,  672,  665,  673,  666,  674,  675,  477,  676,  677,
      678,  679,  680,  476,  476,  476,  715,  716,  717,  667,
      545,  668,  669,  670,  718,  719,  720,  671,  721,  672,

      722,  673,  723,  674,  675,  724,  676,  677,  678,  679,
      680,  639,  725,  726,  715,  716,  717,  727,  728,  729,
      730,  731,  718,  719,  720,  732,  721,  733,  722,  734,
      723,  736,  737,  724,  738,  739,  740,  741,  743,  744,
      725,  726,  745,  746,  747,  727,  728,  729,  730,  731,
      748,  751,  752,  732,  753,  733,  749,  734,  754,  736,
      737,  755,  738,  739,  740,  741,  743,  744,  756,  750,
      745,  746,  747,  757,  758,  759,  760,  761,  748,  751,
      752,  762,  753,  763,  749,  764,  754,  765,  766,  755,
      768,  769,  770,  771,  772,  773,  756,  750,  778,  779,

      808,  757,  758,  759,  760,  761,  795,  796,  809,  762,
      810,  763,  811,  764,  812,  765,  766,  813,  768,  769,
      770,  771,  772,  773,  814,  815,  816,  817,  808,  818,
      819,  820,  821,  823,  824,  735,  809,  825,  810,  826,
      811,  827,  812,  742,  828,  813,  829,  830,  833,  834,
      831,  835,  814,  815,  816,  817,  836,  818,  819,  820,
      821,  823,  824,  832,  837,  825,  461,  826,  838,  827,
      839, 1022,  828,  459,  829,  830,  833,  834,  831,  835,
      778,  779,  965,  966,  836,  967,  968,  969,  970,  971,
      972,  832,  837, 1021,  767, 1020,  838, 1019,  839,  844,

      844,  844,  844,  844,  844,  844,  844,  844,  844,  844,
      844,  844,  844,  844,  844,  844,  844,  844,  844,  844,
      844,  844,  844,  844,  844,  844,  844,  844,  844,  844,
      844,  873,  844,  874,  875,  876,  877,  878,  879,  880,
      882,  884,  885,  886,  887,  888,  889,  890,  920,  921,
      922,  923,  924,  947,  948,  949,  974,  975, 1018,  873,
     1017,  874,  875,  876,  877,  878,  879,  880,  882,  884,
      885,  886,  887,  888,  889,  890,  920,  921,  922,  923,
      924,  947,  948,  949,  992,  992,  992,  992,  992,  992,
      992,  992,  992,  992,  992,  992,  992,  992,  992,  992,

      992,  992,  992,  992,  992,  992,  992,  992,  992,  992,
      992,  992,  992,  992,  992,  992, 1013,  992,  993,  993,
      993,  993,  993,  993,  993,  993,  993,  993,  993,  993,
      993,  993,  993,  993, 1010, 1011,  965,  966,  967,  968,
      969,  970,  971,  972, 1014, 1015,  883,  993,  993,  993,
      993,  993,  993,  993,  993,  993,  993,  993,  993,  993,
      993,  993,  993, 1012,  993,  994,  994,  994,  994,  994,
      994,  994,  994,  994,  994,  994,  994,  994,  994,  994,
      994,  994,  994,  994,  994,  994,  994,  994,  994,  994,
      994,  994,  994,  994,  994,  994,  994, 1009,  994,  995,

      995,  995,  995,  995,  995,  995,  995,  995,  995,  995,
      995,  995,  995,  995,  995,  995,  995,  995,  995,  995,
      995,  995,  995,  995,  995,  995,  995,  995,  995,  995,
      995, 1008,  995,  997,  997,  997,  997,  997,  997,  997,
      997,  997,  997,  998,  997,  997,  997,  997,  997,  997,
      997,  997,  997,  997,  997,  997,  997,  997,  997,  997,
      997,  997,  997,  997,  997, 1016,  997, 1024, 1024, 1024,
     1024, 1024, 1024, 1024, 1024, 1024, 1024, 1024, 1024, 1024,
     1024, 1024, 1024, 1010, 1011, 1032, 1033, 1034, 1015, 1034,
     1015, 1034, 1015, 1016, 1024, 1024, 1024, 1024, 1024, 1024,

     1024, 1024, 1024, 1024, 1024, 1024, 1024, 1024, 1024, 1024,
     1007, 1024, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027,
     1027, 1027, 1028, 1027, 1027, 1027, 1027, 1027, 1027, 1027,
     1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027,
     1027, 1027, 1027, 1027, 1006, 1027, 1038, 1038, 1038, 1038,
     1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038,
     1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038,
     1038, 1038, 1038, 1038, 1038, 1038, 1038, 1038, 1005, 1038,
     1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027,
     1027, 1027, 1027, 1027, 1027, 1027, 1032, 1033,   67,   67,

       67,   69, 1004,   69,   77, 1003,   77,  475,  475, 1002,
     1001, 1000,  999,  996,  991,  990,  989,  988,  987,  986,
      985,  984,  983,  982,  981,  980,  979,  978,  977,  976,
      973,  964,  963,  962,  961,  960,  959,  958,  957,  956,
      955,  954,  953,  952,  951,  950,  946,  945,  944,  943,
      942,  941,  940,  939,  938,  937,  936,  935,  934,  933,
      932,  931,  930,  929,  928,  927,  926,  925,  882,  919,
      918,  917,  916,  915,  914,  913,  912,  911,  910,  909,
      908,  907,  906,  905,  904,  903,  902,  901,  900,  899,
      898,  897,  896,  895,  894,  893,  892,  891,  881,  872,

      871,  870,  869,  868,  867,  866,  865,  864,  863,  862,
      861,  860,  859,  858,  857,  856,  855,  854,  853,  852,
      851,  850,  849,  848,  847,  846,  845,  843,  842,  841,
      840,  766,  741,  822,  734,  807,  806,  805,  804,  803,
      802,  801,  800,  799,  798,  797,  794,  793,  792,  791,
      790,  789,  788,  787,  786,  785,  784,  783,  782,  781,
      780,  777,  776,  775,  774,  638,  714,  713,  712,  711,
      710,  709,  708,  707,  706,  705,  704,  703,  702,  701,
      700,  699,  698,  697,  696,  695,  694,  693,  692,  691,
      690,  689,  686,  685,  684,  683,  682,  681,  635,  510,

      608,  607,  606,  605,  604,  603,  602,  601,  600,  599,
      598,  597,  596,  595,  594,  593,  592,  591,  590,  589,
      588,  587,  586,  585,  584,  581,  580,  579,  578,  577,
      576,  575,  431,  485,  484,  483,  482,  481,  480,  479,
      478,  474,  473,  472,  471,  470,  326,  469,  468,  467,
      466,  465,  456,  455,  454,  453,  452,  449,  248,  399,
      342,  340,  339,  338,   62,   62,  326,  150,  336,  335,
      334,  333,  330,  329,  328,  327,  324,  324,  326,  323,
      322,  320,  319,  318,  315,  314,  311,  306,  305,  304,
      303,  302,  299,  276,  228,  217,  200,   68,  189,  188,

       62,  184,  150,   62,  147,   70,   68, 1050,    3, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050
    } ;

static const flex_int16_t yy_chk[2255] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    5,    5,    5,    6,    6,
        6,   17,    7,    7,    7,   51,   51,   56,   23,   18,
       56,   17,   17,   17,   17,   17, 1048,   19,   17,   18,
       18,   18,   18,   18,    7,   22,   18,   19,   19,   19,
       19,   19,   31,   17,   19,   22,   23,   22,   22,   22,
       24,   18,   22,   24,   22,   22,   17,   24,  301,   19,

     1047,   27,    7,   22,   18,   28,   34,  301,   36,   28,
       31,   17,   19,   22,   27,   22,   22,   22,   24,   18,
       22,   24,   22,   22,   25,   24,   26,   19,   25,   27,
       37,   32,   25,   28,   34,   32,   36,   28,   25,   26,
       35,   66,   27,   35,   25,   26,   57,   32,   35,   54,
       54,  307,   25,   35,   26,  307,   25,   61,   37,   32,
       25,   61,   61,   32,   41,   57,   25,   26,   35,   66,
       41,   35,   25,   26,   30,   32,   35,    5,   30,   38,
        6,   35,    5,    5,    7,    6,    6,   33,   30,    7,
        7,   33,   41,   59,   30,   33,  309,   78,   41,   38,

      309,   33,   30,   45,   33, 1046,   30,   38,   62,   62,
       62,   27,  152,  152,   39,   33,   30,   45,   39,   33,
       42,   39,   30,   33,   42,   78,   59,   38,   39,   33,
       42,   45,   33,   42,   39,  158,  158,   40,   25,   71,
       40,   43,   39,   80,   43,   45,   39,   40,   42,   39,
     1045,   43,   42,   40,   71,   58,   39,   58,   42, 1044,
       58,   42,   39,   73,   74,   40,   82,   71,   40,   43,
       84,   80,   43,   85,   58,   40,   53, 1043,   53,   43,
       53,   40,   71,   53,   73,   74, 1042,   53,   53,   53,
       53,   55,   53,   53,   82,   53, 1041,   55,   84,   55,

       53,   85,  581,   53,  581,   53,   86,   72,   53,   87,
       88, 1040,   73,   74,   53,   53,   53,   72,   72,   72,
       72,   72,   89,   91,   72,  159,  159, 1039,   39,   76,
       76,   76,   76,   76,   86,   93,   93,   87,   88,   72,
       62,  325,   94,   90,   75,   62,   62,   90, 1036,   96,
       89,   91,   72,   75,   75,   75,   75,   75,   75,   97,
       92,   75,  102,   93,   93,   99,  103,   72,   92,   92,
       94,   90,   99,  104,  105,   90,   75,   96,   97,  106,
     1035,   99,  100,  108,  310,  110,  111,  310,   92,   75,
      102,  161,  161,   99,  103,  100,   92,   92,  115,  100,

       99,  104,  105, 1031,   75,  100,   97,  106,  107,   99,
      113,  108,  107,  110,  111,  107,  107,  107,  112,  113,
      115,  116,  114,  100,  117,  118,  112,  100,  119,  120,
      121,  114, 1030,  100,  124,  112,  107,  114,  113,  125,
      107, 1029,  112,  107,  107,  107,  112,  113,  115,  116,
      114,  126,  117,  118,  112,  129,  119,  120,  121,  114,
      123,  126,  124,  112,  127,  114,  132,  125,  123,  127,
      112,  127,  126,  127,  135,  325,  130,  133, 1022,  126,
      136,  127,  138,  129,  137,  139,  140,  135,  123,  126,
      141,  137,  127,  143,  132,  144,  123,  127,  130,  127,

      126,  127,  145,  133,  142,  146,  133,  126,  136,  127,
      138,  148,  137,  139,  140,  135,  142,  142,  141,  137,
      149,  143,  164,  144,  168,  186,  130, 1021,  191, 1017,
      145,  133,  114,  146,  133,  174,  174,  186,  180,  148,
      190,  193,  195,  198,  142,  142,  192, 1013,  149,  191,
      164,  202,  168,  171,  171,  171,  171,  171,  201,  203,
      205,  206,  174,  171,  171,  171,  180,  192,  190,  193,
      195,  198,  207,  209,  211,  201,  171,  191,  210,  212,
      202,  213,  214,  215,  216,  217,  214,  203,  205,  206,
      218,  210,  219,  215,  220,  192, 1012,  221,  223,  225,

      207,  209,  211,  201,  222,  226,  227,  212,  202,  213,
      214,  215,  216,  217,  214,  228,  229,  222,  218,  210,
      219,  215,  220,  221,  164,  230,  223,  225,  231,  236,
     1009,  232,  222,  226,  227,  233,  234,  235,  237,  235,
      239,  238,  240,  228,  229,  222,  241,  241,  242,  247,
      248,  221,  249,  230,  238,  250,  255,  231,  231,  232,
      244,  256,  236,  233,  234,  235,  237,  235,  239,  255,
      240,  244,  244,  253,  241,  241,  242,  247,  248,  259,
      249,  260,  238,  250,  256,  231,  231,  244,  244,  253,
      236,  261,  262,  263,  265,  267,  266,  255,  268,  244,

      244,  253,  269,  270,  271,  272,  273,  259,  276,  260,
      266,  277,  256,  265,  275,  244,  244,  253,  279,  261,
      262,  263,  265,  267,  266,  280,  268,  282,  275,  275,
      269,  270,  271,  272,  273,  285,  276,  287,  266,  277,
      289,  265,  275,  286,  286,  291,  279,  292,  293,  294,
      295,  296,  337,  280,  299,  282,  275,  275,  341,  342,
      271,  308,  344,  285,  346,  287,  347,  299,  289,  348,
      349,  286,  286,  291,  308,  292,  293,  294,  295,  296,
      337,  350,  353,  354,  355,  356,  341,  342,  357,  358,
      344,  359,  346,  360,  347, 1008,  362,  348,  349,  363,

      364,  365,  367,  368,  369,  370,  371,  372,  373,  350,
      353,  354,  355,  356,  374,  375,  357,  358,  377,  359,
      378,  360,  379,  277,  362,  380,  381,  363,  364,  365,
      367,  368,  369,  370,  371,  372,  373,  382,  386,  389,
      390,  391,  374,  375,  392,  393,  377,  395,  378,  396,
      379,  398,  400,  380,  381,  400,  401,  402,  403,  392,
      404,  405,  407,  409,  411,  382,  386,  389,  390,  391,
      412,  414,  392,  393,  416,  395,  417,  396,  415,  398,
      400,  418,  419,  400,  401,  402,  403,  392,  404,  405,
      407,  409,  411,  420,  415,  421,  422,  425,  412,  414,

      424,  426,  416,  427,  417,  428,  415,  429,  430,  418,
      419,  431,  433,  424,  434,  370,  435,  436,  437,  438,
      439,  420,  415,  421,  422,  425,  440,  441,  443,  426,
      444,  427,  445,  428,  446,  429,  430,  454,  454,  431,
      433,  424,  434,  475,  435,  436,  437,  438,  439,  487,
      490,  492,  493,  494,  440,  441,  443,  495,  444,  496,
      445,  497,  446,  498,  499,  500,  501,  502,  503,  504,
      505,  506,  507,  508,  512,  513,  514,  487,  490,  492,
      493,  494,  515,  516,  517,  495,  518,  496,  521,  497,
      522,  498,  499,  500,  501,  502,  503,  504,  505,  506,

      507,  508,  512,  513,  514,  527,  529,  532,  533,  534,
      515,  516,  517,  535,  518,  536,  521,  537,  522,  538,
      539,  540,  532,  542,  543,  541,  544,  545,  546,  548,
      549,  550,  551,  527,  529,  532,  533,  534,  541,  552,
      554,  535,  556,  536,  557,  537,  558,  538,  539,  540,
      532,  542,  543,  541,  544,  545,  546,  548,  549,  550,
      551,  559,  560,  562,  563,  564,  541,  552,  554,  565,
      556,  566,  557,  567,  558,  568,  569,  475,  570,  571,
      572,  573,  574,  600,  600,  600,  609,  611,  614,  559,
      560,  562,  563,  564,  615,  616,  617,  565,  618,  566,

      619,  567,  620,  568,  569,  621,  570,  571,  572,  573,
      574,  527,  622,  624,  609,  611,  614,  625,  626,  627,
      628,  629,  615,  616,  617,  630,  618,  631,  619,  632,
      620,  633,  634,  621,  635,  637,  640,  641,  643,  644,
      622,  624,  645,  647,  648,  625,  626,  627,  628,  629,
      649,  651,  652,  630,  655,  631,  650,  632,  659,  633,
      634,  660,  635,  637,  640,  641,  643,  644,  661,  650,
      645,  647,  648,  663,  664,  665,  666,  668,  649,  651,
      652,  669,  655,  670,  650,  671,  659,  672,  673,  660,
      674,  675,  676,  677,  678,  679,  661,  650,  685,  685,

      717,  663,  664,  665,  666,  668,  702,  702,  718,  669,
      719,  670,  721,  671,  723,  672,  673,  724,  674,  675,
      676,  677,  678,  679,  725,  726,  727,  728,  717,  729,
      730,  732,  733,  743,  744,  632,  718,  745,  719,  746,
      721,  749,  723,  641,  750,  724,  754,  755,  758,  762,
      757,  763,  725,  726,  727,  728,  765,  729,  730,  732,
      733,  743,  744,  757,  770,  745, 1007,  746,  772,  749,
      773, 1006,  750, 1005,  754,  755,  758,  762,  757,  763,
      844,  844,  941,  941,  765,  942,  942,  943,  943,  944,
      944,  757,  770, 1004,  673, 1003,  772, 1002,  773,  778,

      778,  778,  778,  778,  778,  778,  778,  778,  778,  778,
      778,  778,  778,  778,  778,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  809,  779,  812,  813,  814,  815,  816,  818,  821,
      823,  825,  826,  830,  831,  832,  834,  837,  875,  877,
      880,  881,  890,  920,  922,  923,  946,  946, 1001,  809,
     1000,  812,  813,  814,  815,  816,  818,  821,  823,  825,
      826,  830,  831,  832,  834,  837,  875,  877,  880,  881,
      890,  920,  922,  923,  965,  965,  965,  965,  965,  965,
      965,  965,  965,  965,  965,  965,  965,  965,  965,  965,

      966,  966,  966,  966,  966,  966,  966,  966,  966,  966,
      966,  966,  966,  966,  966,  966,  997,  966,  967,  967,
      967,  967,  967,  967,  967,  967,  967,  967,  967,  967,
      967,  967,  967,  967,  991,  991,  992,  992,  993,  993,
      994,  994,  995,  995,  998,  998,  823,  968,  968,  968,
      968,  968,  968,  968,  968,  968,  968,  968,  968,  968,
      968,  968,  968,  996,  968,  969,  969,  969,  969,  969,
      969,  969,  969,  969,  969,  969,  969,  969,  969,  969,
      969,  970,  970,  970,  970,  970,  970,  970,  970,  970,
      970,  970,  970,  970,  970,  970,  970,  989,  970,  971,

      971,  971,  971,  971,  971,  971,  971,  971,  971,  971,
      971,  971,  971,  971,  971,  972,  972,  972,  972,  972,
      972,  972,  972,  972,  972,  972,  972,  972,  972,  972,
      972,  988,  972,  974,  974,  974,  974,  974,  974,  974,
      974,  974,  974,  974,  974,  974,  974,  974,  974,  975,
      975,  975,  975,  975,  975,  975,  975,  975,  975,  975,
      975,  975,  975,  975,  975,  999,  975, 1010, 1010, 1010,
     1010, 1010, 1010, 1010, 1010, 1010, 1010, 1010, 1010, 1010,
     1010, 1010, 1010, 1024, 1024, 1025, 1025, 1026, 1026, 1027,
     1027, 1028, 1028,  999, 1011, 1011, 1011, 1011, 1011, 1011,

     1011, 1011, 1011, 1011, 1011, 1011, 1011, 1011, 1011, 1011,
      987, 1011, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,
     1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1015, 1015,
     1015, 1015, 1015, 1015, 1015, 1015, 1015, 1015, 1015, 1015,
     1015, 1015, 1015, 1015,  986, 1015, 1032, 1032, 1032, 1032,
     1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032,
     1032, 1032, 1033, 1033, 1033, 1033, 1033, 1033, 1033, 1033,
     1033, 1033, 1033, 1033, 1033, 1033, 1033, 1033,  985, 1033,
     1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
     1034, 1034, 1034, 1034, 1034, 1034, 1038, 1038, 1051, 1051,

     1051, 1052,  984, 1052, 1053,  983, 1053, 1054, 1054,  981,
      980,  979,  976,  973,  964,  963,  962,  961,  960,  959,
      958,  957,  956,  955,  954,  953,  952,  951,  950,  949,
      945,  940,  939,  938,  937,  936,  934,  933,  932,  931,
      930,  929,  928,  927,  926,  925,  912,  911,  910,  909,
      908,  907,  906,  905,  904,  903,  902,  901,  900,  899,
      898,  897,  896,  895,  894,  893,  892,  891,  883,  872,
      871,  870,  869,  868,  867,  866,  865,  864,  863,  862,
      861,  860,  859,  858,  857,  856,  855,  854,  853,  852,
      851,  850,  849,  845,  843,  842,  841,  840,  822,  807,

      806,  805,  804,  803,  802,  801,  800,  799,  798,  797,
      796,  795,  794,  793,  792,  791,  790,  789,  788,  787,
      786,  785,  784,  783,  782,  781,  780,  777,  776,  775,
      774,  767,  742,  738,  735,  714,  712,  711,  710,  709,
      708,  707,  706,  705,  704,  703,  701,  700,  699,  698,
      697,  696,  695,  694,  693,  692,  691,  690,  688,  687,
      686,  684,  683,  682,  681,  639,  608,  607,  606,  605,
      604,  603,  602,  601,  599,  598,  597,  596,  595,  594,
      593,  592,  591,  590,  589,  588,  587,  586,  585,  584,
      583,  582,  580,  579,  578,  577,  576,  575,  520,  511,

      485,  484,  483,  482,  481,  480,  479,  478,  477,  474,
      473,  472,  471,  470,  469,  468,  466,  465,  464,  463,
      462,  460,  458,  456,  455,  453,  452,  451,  450,  449,
      448,  447,  432,  336,  335,  334,  333,  332,  331,  329,
      328,  323,  322,  320,  319,  318,  317,  315,  314,  313,
      312,  311,  306,  305,  304,  303,  302,  300,  251,  245,
      200,  197,  196,  194,  189,  188,  187,  185,  184,  183,
      182,  181,  179,  178,  177,  176,  175,  173,  172,  170,
      169,  167,  166,  165,  163,  162,  160,  157,  156,  155,
      154,  153,  151,  131,  101,   95,   81,   67,   65,   64,

       63,   60,   52,   50,   48,   13,    8,    3, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[195] =
    {   0,
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
/*
    SPDX-FileCopyrightText: 2020 Volker Krause <vkrause@kde.org>
    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "openinghoursparser_p.h"

#include <cstring>

#define YY_USER_ACTION yylloc->first_column = yylloc->last_column; yylloc->last_column += yyleng;

/* technically the case of all tokens is clearly defined, but reality ignores that in parts, so we do the same */

#define INITIAL 0

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1051 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1050 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
{}
	YY_BREAK
case 2:
YY_RULE_SETUP
{
    yylval->num = std::strtol(yytext, nullptr, 10);
    if (yyleng == 4) {
        if ((yylval->num > 2000 && yylval->num < 2100) || (yylval->num >= 1000 && (yylval->num % 100) >= 60)) {
            return T_YEAR;
        }
        if (yylval->num <= 2400 && (yylval->num % 100) < 60) {
            return T_4DIGIT_TIME;
        }
    }
    return T_INTEGER;
}
	YY_BREAK
case 3:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ return T_NORMAL_RULE_SEPARATOR; } // technically this should have space after the semicolon, but that is not always followed in OSM data
	YY_BREAK
case 4:
YY_RULE_SETUP
{ return T_ADDITIONAL_RULE_SEPARATOR; }
	YY_BREAK
case 5:
YY_RULE_SETUP
{ return T_FALLBACK_SEPARATOR; } // technically this should have a space on either side, but that is not always followed in OSM data
	YY_BREAK
case 6:
YY_RULE_SETUP
{ yylval->state = State::Open;    return T_STATE; }
	YY_BREAK
case 7:
YY_RULE_SETUP
{ yylval->state = State::Closed;  return T_STATE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
{ yylval->state = State::Off;  return T_STATE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
{ yylval->state = State::Unknown; return T_STATE; }
	YY_BREAK
case 10:
YY_RULE_SETUP
{ return T_24_7; }
	YY_BREAK
case 11:
YY_RULE_SETUP
{ return T_PLUS; }
	YY_BREAK
case 12:
YY_RULE_SETUP
{ return T_MINUS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
{ return T_SLASH; }
	YY_BREAK
case 14:
YY_RULE_SETUP
{ return T_COLON; }
	YY_BREAK
case 15:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ return T_COMMA; }
	YY_BREAK
case 16:
YY_RULE_SETUP
{} // eat trailing commas/semicolons, while invalid those occur commonly in OSM data. Practically this is done indirectly in combination with the above rules as we cannot lookahead to EOF
	YY_BREAK
case 17:
YY_RULE_SETUP
{ yylval->time = { Time::Dawn,    0, 0 }; return T_EVENT; }
	YY_BREAK
case 18:
YY_RULE_SETUP
{ yylval->time = { Time::Sunrise, 0, 0 }; return T_EVENT; }
	YY_BREAK
case 19:
YY_RULE_SETUP
{ yylval->time = { Time::Sunset , 0, 0 }; return T_EVENT; }
	YY_BREAK
case 20:
YY_RULE_SETUP
{ yylval->time = { Time::Dusk,    0, 0 }; return T_EVENT; }
	YY_BREAK
case 21:
YY_RULE_SETUP
{ return T_LBRACKET; }
	YY_BREAK
case 22:
YY_RULE_SETUP
{ return T_RBRACKET; }
	YY_BREAK
case 23:
YY_RULE_SETUP
{ return T_LPAREN; }
	YY_BREAK
case 24:
YY_RULE_SETUP
{ return T_RPAREN; }
	YY_BREAK
case 25:
YY_RULE_SETUP
{ return T_PH; }
	YY_BREAK
case 26:
YY_RULE_SETUP
{ return T_SH; }
	YY_BREAK
case 27:
YY_RULE_SETUP
{ return T_KEYWORD_DAY; }
	YY_BREAK
case 28:
YY_RULE_SETUP
{ return T_KEYWORD_DAY; }
	YY_BREAK
case 29:
YY_RULE_SETUP
{ return T_KEYWORD_WEEK; }
	YY_BREAK
case 30:
YY_RULE_SETUP
{ return T_EASTER; }
	YY_BREAK
case 31:
YY_RULE_SETUP
{ return T_WHITSUN; } // non-standard, will be turned into "easter +49 days"
	YY_BREAK
/* am/pm time format support, non-standard and has to appear before the generic number token. */
case 32:
YY_RULE_SETUP
{ yylval->num = std::strtol(yytext, nullptr, 10); return T_ALT_TIME_AM; }
	YY_BREAK
case 33:
YY_RULE_SETUP
{ yylval->num = std::strtol(yytext, nullptr, 10); return T_ALT_TIME_PM; }
	YY_BREAK
/* technically weekday names should be two letter English abbreviations, but reality is more creative */
case 34:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 35:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 36:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 37:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 38:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 39:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 40:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
case 41:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 42:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 43:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 44:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 45:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 46:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 47:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 48:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 49:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
case 50:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 51:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 52:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 53:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 54:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 55:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 56:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* same for month names, technically those should be three letter English abbreviations */
case 57:
YY_RULE_SETUP
{ yylval->num = 1; return T_MONTH; }
	YY_BREAK
case 58:
YY_RULE_SETUP
{ yylval->num = 2; return T_MONTH; }
	YY_BREAK
case 59:
YY_RULE_SETUP
{ yylval->num = 3; return T_MONTH; }
	YY_BREAK
case 60:
YY_RULE_SETUP
{ yylval->num = 4; return T_MONTH; }
	YY_BREAK
case 61:
YY_RULE_SETUP
{ yylval->num = 6; return T_MONTH; }
	YY_BREAK
case 62:
YY_RULE_SETUP
{ yylval->num = 7; return T_MONTH; }
	YY_BREAK
case 63:
YY_RULE_SETUP
{ yylval->num = 8; return T_MONTH; }
	YY_BREAK
case 64:
YY_RULE_SETUP
{ yylval->num = 9; return T_MONTH; }
	YY_BREAK
case 65:
YY_RULE_SETUP
{ yylval->num = 10; return T_MONTH; }
	YY_BREAK
case 66:
YY_RULE_SETUP
{ yylval->num = 11; return T_MONTH; }
	YY_BREAK
case 67:
YY_RULE_SETUP
{ yylval->num = 12; return T_MONTH; }
	YY_BREAK
case 68:
YY_RULE_SETUP
{ yylval->num = 1; return T_MONTH; }
	YY_BREAK
case 69:
YY_RULE_SETUP
{ yylval->num = 2; return T_MONTH; }
	YY_BREAK
case 70:
YY_RULE_SETUP
{ yylval->num = 3; return T_MONTH; }
	YY_BREAK
case 71:
YY_RULE_SETUP
{ yylval->num = 4; return T_MONTH; }
	YY_BREAK
case 72:
YY_RULE_SETUP
{ yylval->num = 5; return T_MONTH; }
	YY_BREAK
case 73:
YY_RULE_SETUP
{ yylval->num = 6; return T_MONTH; }
	YY_BREAK
case 74:
YY_RULE_SETUP
{ yylval->num = 7; return T_MONTH; }
	YY_BREAK
case 75:
YY_RULE_SETUP
{ yylval->num = 8; return T_MONTH; }
	YY_BREAK
case 76:
YY_RULE_SETUP
{ yylval->num = 9; return T_MONTH; }
	YY_BREAK
case 77:
YY_RULE_SETUP
{ yylval->num = 10; return T_MONTH; }
	YY_BREAK
case 78:
YY_RULE_SETUP
{ yylval->num = 11; return T_MONTH; }
	YY_BREAK
case 79:
YY_RULE_SETUP
{ yylval->num = 12; return T_MONTH; }
	YY_BREAK
/* Month names in French */
case 80:
YY_RULE_SETUP
{ yylval->num = 1; return T_MONTH; }
	YY_BREAK
case 81:
YY_RULE_SETUP
{ yylval->num = 2; return T_MONTH; }
	YY_BREAK
case 82:
YY_RULE_SETUP
{ yylval->num = 3; return T_MONTH; }
	YY_BREAK
case 83:
YY_RULE_SETUP
{ yylval->num = 4; return T_MONTH; }
	YY_BREAK
case 84:
YY_RULE_SETUP
{ yylval->num = 5; return T_MONTH; }
	YY_BREAK
case 85:
YY_RULE_SETUP
{ yylval->num = 6; return T_MONTH; }
	YY_BREAK
case 86:
YY_RULE_SETUP
{ yylval->num = 7; return T_MONTH; }
	YY_BREAK
case 87:
YY_RULE_SETUP
{ yylval->num = 8; return T_MONTH; }
	YY_BREAK
case 88:
YY_RULE_SETUP
{ yylval->num = 9; return T_MONTH; }
	YY_BREAK
case 89:
YY_RULE_SETUP
{ yylval->num = 10; return T_MONTH; }
	YY_BREAK
case 90:
YY_RULE_SETUP
{ yylval->num = 11; return T_MONTH; }
	YY_BREAK
case 91:
YY_RULE_SETUP
{ yylval->num = 12; return T_MONTH; }
	YY_BREAK
/* Month names in Russian */
case 92:
YY_RULE_SETUP
{ yylval->num = 1; return T_MONTH; }
	YY_BREAK
case 93:
YY_RULE_SETUP
{ yylval->num = 2; return T_MONTH; }
	YY_BREAK
case 94:
YY_RULE_SETUP
{ yylval->num = 3; return T_MONTH; }
	YY_BREAK
case 95:
YY_RULE_SETUP
{ yylval->num = 4; return T_MONTH; }
	YY_BREAK
case 96:
YY_RULE_SETUP
{ yylval->num = 5; return T_MONTH; }
	YY_BREAK
case 97:
YY_RULE_SETUP
{ yylval->num = 6; return T_MONTH; }
	YY_BREAK
case 98:
YY_RULE_SETUP
{ yylval->num = 7; return T_MONTH; }
	YY_BREAK
case 99:
YY_RULE_SETUP
{ yylval->num = 8; return T_MONTH; }
	YY_BREAK
case 100:
YY_RULE_SETUP
{ yylval->num = 9; return T_MONTH; }
	YY_BREAK
case 101:
YY_RULE_SETUP
{ yylval->num = 10; return T_MONTH; }
	YY_BREAK
case 102:
YY_RULE_SETUP
{ yylval->num = 11; return T_MONTH; }
	YY_BREAK
case 103:
YY_RULE_SETUP
{ yylval->num = 12; return T_MONTH; }
	YY_BREAK
/* Month abbreviations in Dutch */
case 104:
YY_RULE_SETUP
{ yylval->num = 3; return T_MONTH; }
	YY_BREAK
case 105:
YY_RULE_SETUP
{ yylval->num = 5; return T_MONTH; }
	YY_BREAK
case 106:
YY_RULE_SETUP
{ yylval->num = 10; return T_MONTH; }
	YY_BREAK
/* different quote types are sometimes mixed and/or used nested, so this is a compromise to catch most of them */
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
{
    yylval->strRef.str = yytext + 1;
    yylval->strRef.len = yyleng - 2;
    return T_COMMENT;
}
	YY_BREAK
case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
{
    int startOffset = 1; int endOffset = 1;
    for (const auto quote : { "\"", "“", "”", "„" }) {
        const int len = std::strlen(quote);
        if (yyleng <= len) {
            continue;
        }
        if (std::strncmp(yytext, quote, len) == 0) {
            startOffset = len;
        }
        if (std::strncmp(yytext + yyleng - len, quote, len) == 0) {
            endOffset = len;
        }
    }
    yylval->strRef.str = yytext + startOffset;
    yylval->strRef.len = yyleng - startOffset - endOffset;
    return T_COMMENT;
}
	YY_BREAK
/* various alternative formats, none of this is remotely compliant with the specification, but appears in reality nevertheless */
/* alternative time formats */
case 109:
YY_RULE_SETUP
{ return T_ALT_TIME_SEP; }
	YY_BREAK
case 110:
YY_RULE_SETUP
{ return T_ALT_TIME_SEP_OR_SUFFIX; }
	YY_BREAK
/* alternative range separators */
case 111:
YY_RULE_SETUP
{ return T_ALT_RANGE_SEP; }
	YY_BREAK
/* localized state names */
case 112:
YY_RULE_SETUP
{ yylval->state = State::Closed; return T_STATE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
{ yylval->state = State::Open;    return T_STATE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
{ yylval->state = State::Unknown; return T_STATE; }
	YY_BREAK
/* German localized day names. */
case 115:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 116:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 117:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 118:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 119:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 120:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 121:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
case 122:
YY_RULE_SETUP
{ return T_PH; }
	YY_BREAK
/* French, Spanish, Italian */
case 123:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
/* French, Italian */
case 124:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
/* German, Spanish, Italian */
case 125:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
/* French */
case 126:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
/* Italian */
case 127:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
/* French, Italian */
case 128:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
/* German */
case 129:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* "Ma" conflicts between Dutch and French+Spanish+Italian...
    "Di" conflicts between Dutch+German and French...
    "Do" conflicts between Dutch+German and Spanish+Italian... */
/* French localized day names. */
case 130:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 131:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 132:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 133:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 134:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 135:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 136:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
case 137:
YY_RULE_SETUP
{ return T_PH; }
	YY_BREAK
/* Spanish localized day names */
case 138:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 139:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 140:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 141:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 142:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 143:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 144:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* Italian localized day names */
case 145:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 146:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 147:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 148:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 149:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 150:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 151:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* Portuguese localized day names */
case 152:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 153:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 154:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 155:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 156:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 157:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
/* Japanese localized day names */
case 158:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 159:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 160:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 161:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 162:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 163:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 164:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
case 165:
YY_RULE_SETUP
{ return T_PH; }
	YY_BREAK
/* Indonesian localized day names */
case 166:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 167:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 168:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 169:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 170:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 171:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 172:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* Russian localized day names */
case 173:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 174:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 175:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 176:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 177:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 178:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 179:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* Dutch localized day names */
case 180:
YY_RULE_SETUP
{ yylval->num = 1; return T_WEEKDAY; }
	YY_BREAK
case 181:
YY_RULE_SETUP
{ yylval->num = 2; return T_WEEKDAY; }
	YY_BREAK
case 182:
YY_RULE_SETUP
{ yylval->num = 3; return T_WEEKDAY; }
	YY_BREAK
case 183:
YY_RULE_SETUP
{ yylval->num = 4; return T_WEEKDAY; }
	YY_BREAK
case 184:
YY_RULE_SETUP
{ yylval->num = 5; return T_WEEKDAY; }
	YY_BREAK
case 185:
YY_RULE_SETUP
{ yylval->num = 6; return T_WEEKDAY; }
	YY_BREAK
case 186:
YY_RULE_SETUP
{ yylval->num = 7; return T_WEEKDAY; }
	YY_BREAK
/* creative rule separators */
case 187:
YY_RULE_SETUP
{ return T_ADDITIONAL_RULE_SEPARATOR; }
	YY_BREAK
/* skip filler words */
/* Note: the 'с' is not an ASCII 'c'! */
case 188:
YY_RULE_SETUP
{}
	YY_BREAK
/* localized time event names */
case 189:
YY_RULE_SETUP
{ yylval->time = { Time::Dawn,    0, 0 }; return T_EVENT; }
	YY_BREAK
case 190:
YY_RULE_SETUP
{ yylval->time = { Time::Dusk,    0, 0 }; return T_EVENT; }
	YY_BREAK
case 191:
YY_RULE_SETUP
{ yylval->time = { Time::Sunrise, 0, 0 }; return T_EVENT; }
	YY_BREAK
case 192:
YY_RULE_SETUP
{ yylval->time = { Time::Sunset , 0, 0 }; return T_EVENT; }
	YY_BREAK
case 193:
YY_RULE_SETUP
{
    //printf("unexpected character: %s at %d:%d\n", yytext, yylloc->first_line, yylloc->first_column);
    return T_INVALID;
}
	YY_BREAK
case 194:
YY_RULE_SETUP
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1051 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1051 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1050);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	if ( c == '\n' )
		
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

